@@ -89,8 +89,8 @@ typedef marpaESLIFRecognizerEventCallback_t (*marpaESLIFRecognizerEventActionRes
 /* ------- ---                   ---------       -----                                              */
 /* STRING  "callout_number"   => LONG or UNDEF   Callout number                                   0 */
 /* STRING  "callout_string"   => STRING or UNDEF Callout string                                   1 */
-/* STRING  "subject"          => ARRAY           Subject                                          2 */
-/* STRING  "pattern"          => STRING          Pattern                                          3 */
+/* STRING  "subject"          => ARRAY OR UNDEF  Subject (*)                                      2 */
+/* STRING  "pattern"          => STRING OR UNDEF Pattern (*)                                      3 */
 /* STRING  "capture_top"      => LONG            Max current capture                              4 */
 /* STRING  "capture_last"     => LONG            Most recently closed capture                     5 */
 /* STRING  "offset_vector"    => ROW of LONGs    Offset vector                                    6 */
@@ -98,6 +98,15 @@ typedef marpaESLIFRecognizerEventCallback_t (*marpaESLIFRecognizerEventActionRes
 /* STRING  "start_match"      => LONG            Current match start attempt offset               8 */
 /* STRING  "current_position" => LONG            Current subject offset                           9 */
 /* STRING  "next_item"        => STRING or UNDEF Next item in the pattern                        10 */
+/* STRING  "grammar_level"    => INT             The grammar level                               11 */
+/* STRING  "symbol_id"        => INT             The symbol identifier                           12 */
+/*                                                                                                  */
+/* (*) By default UNDEF is returned, unless ESLIF is compiled without the MARPAESLIF_NTRACE define. */
+/*     This is voluntarily choice for performance reasons.                                          */
+/*     In production mode ESLIF guarantees that:                                                    */
+/*     - subject correspond to the output of marpaESLIFRecognizer_input()                           */
+/*     - pattern can be retreived using the symbol's description using symbol_id value in input to  */
+/*       marpaESLIFGrammar_symbolproperty_by_levelb().                                              */
 /*                                                                                                  */
 /* ESLIF guarantees that this marpaESLIFCalloutBlockp is filled in this exact order, therefore      */
 /* using an indice in the marpaESLIFCalloutBlockEnum_t enum below is safe.                          */
@@ -114,6 +123,8 @@ typedef enum marpaESLIFCalloutBlockEnum {
                                          MARPAESLIFCALLOUTBLOCK_START_MATCH,
                                          MARPAESLIFCALLOUTBLOCK_CURRENT_POSITION,
                                          MARPAESLIFCALLOUTBLOCK_NEXT_ITEM,
+                                         MARPAESLIFCALLOUTBLOCK_GRAMMAR_LEVEL,
+                                         MARPAESLIFCALLOUTBLOCK_SYMBOL_ID,
                                          _MARPAESLIFCALLOUTBLOCK_SIZE
 } marpaESLIFCalloutBlockEnum_t;
 
@@ -616,6 +627,7 @@ extern "C" {
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_discard_last_tryb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, char **trysp, size_t *trylp);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_discard_lastb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, char **lastsp, size_t *lastlp);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_isEofb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, short *eofbp);
+  marpaESLIF_EXPORT short                         marpaESLIFRecognizer_isStartCompleteb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, short *completebp);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_event_onoffb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, char *symbols, marpaESLIFEventType_t eventSeti, short onoffb);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_eventb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, size_t *eventArraylp, marpaESLIFEvent_t **eventArraypp);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_progressLogb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, int starti, int endi, genericLoggerLevel_t logleveli);
@@ -627,6 +639,8 @@ extern "C" {
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_last_completedb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, char *names, char **offsetpp, size_t *lengthlp);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_hook_discardb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, short discardOnOffb);
   marpaESLIF_EXPORT short                         marpaESLIFRecognizer_hook_discard_switchb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp);
+  /* TAKE CARE: trying to match an external to an existing recognizer will use, in case of a match, the RECOGNIZER's import configuration, not the external symbol */
+  marpaESLIF_EXPORT short                         marpaESLIFRecognizer_symbol_tryb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, marpaESLIFSymbol_t *marpaESLIFSymbolp, short *matchbp);
   marpaESLIF_EXPORT void                          marpaESLIFRecognizer_freev(marpaESLIFRecognizer_t *marpaESLIFRecognizerp);
 
   marpaESLIF_EXPORT marpaESLIFValue_t            *marpaESLIFValue_newp(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, marpaESLIFValueOption_t *marpaESLIFValueOptionp);
@@ -722,10 +736,9 @@ extern "C" {
   /* An external symbol can be used directly inside the recognizer phase in the current input stream. The later will automatically expand if needed */
   /* as in normal recognizer lifetime. */
   /* It can be also used outside of any grammar on a free input string */
-  /* If there is match, *matchbp will contain a true value, else a false value */
-  /* If there is match and importer is set, the later is called */
+  /* If there is a match, *matchbp will contain a true value, else a false value */
+  /* If there is a match and importer is set, the later is called */
   marpaESLIF_EXPORT short                        marpaESLIFSymbol_tryb(marpaESLIFSymbol_t *marpaESLIFSymbolp, char *inputs, size_t inputl, short *matchbp);
-  marpaESLIF_EXPORT short                        marpaESLIFRecognizer_symbol_tryb(marpaESLIFRecognizer_t *marpaESLIFRecognizerp, marpaESLIFSymbol_t *marpaESLIFSymbolp, short *matchbp);
   marpaESLIF_EXPORT void                         marpaESLIFSymbol_freev(marpaESLIFSymbol_t *marpaESLIFSymbolp);
 #ifdef __cplusplus
 }
